#
# spec file for package apache-commons-logging
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2000-2007, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name  logging
%define short_name commons-%{base_name}
Name:           apache-%{short_name}
Version:        1.3.5
Release:        1.1
Summary:        Apache Commons Logging
License:        Apache-2.0
URL:            https://commons.apache.org/%{base_name}
Source0:        https://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        https://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz.asc
Source2:        %{name}.keyring
Source5:        build.xml
Source6:        build.properties
Patch0:         commons-logging-1.3.3-dependencies.patch
BuildRequires:  ant
BuildRequires:  glassfish-servlet-api
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  reload4j
Requires:       java >= 1.8
Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       %{short_name} = %{version}-%{release}
Obsoletes:      %{short_name} < %{version}
BuildArch:      noarch

%description
The commons-logging package provides a simple, component oriented
interface (org.apache.commons.logging.Log) together with wrappers for
logging systems. The user can choose at runtime which system they want
to use. In addition, a small number of basic implementations are
provided to allow users to use the package standalone.
commons-logging was heavily influenced by Avalon's Logkit and Log4J. The
commons-logging abstraction is meant to minimize the differences between
the two, and to allow a developer to not tie himself to a particular
logging implementation.

%prep
%autosetup -p1 -n %{short_name}-%{version}-src

cp %{SOURCE5} build.xml
cp %{SOURCE6} build.properties

sed -i 's/\r//' RELEASE-NOTES.txt LICENSE.txt

%pom_remove_parent .

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

export CLASSPATH=$(build-classpath \
                   plexus/ \
                  ):target/classes:target/test-classes
ant \
  -Dmaven.mode.offline=true -lib %{_javadir} \
  -Dlog4j12.jar=$(find-jar reload4j/reload4j) -Dservletapi.jar=$(find-jar glassfish-servlet-api) \
  dist

%install
# jars
install -d -m 755 %{buildroot}%{_javadir}
install -p -m 644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar
install -p -m 644 target/%{short_name}-api-%{version}.jar %{buildroot}%{_javadir}/%{name}-api.jar
install -p -m 644 target/%{short_name}-adapters-%{version}.jar %{buildroot}%{_javadir}/%{name}-adapters.jar

pushd %{buildroot}%{_javadir}
for jar in %{name}*; do
    ln -sf ${jar} `echo $jar| sed "s|apache-||g"`
done
popd

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}/%{_mavenpomdir}/%{short_name}.pom
%add_maven_depmap %{short_name}.pom %{short_name}.jar -a "org.apache.commons:%{short_name}","apache:%{short_name}"
%add_maven_depmap %{short_name}:%{short_name}::api:%{version} %{short_name}-api.jar -a "%{short_name}:%{short_name}-api","org.apache.commons:%{short_name}-api","apache:%{short_name}-api"
%add_maven_depmap %{short_name}:%{short_name}::adapters:%{version} %{short_name}-adapters.jar -a "%{short_name}:%{short_name}-adapters","org.apache.commons:%{short_name}-adapters","apache:%{short_name}-adapters"

%files -f .mfiles
%{_javadir}/%{name}*.jar
%license LICENSE.txt
%doc PROPOSAL.html RELEASE-NOTES.txt NOTICE.txt

%changelog
* Tue Apr  1 2025 Gus Kenion <gus.kenion@suse.com>
- Upgrade to 1.3.5
  * Fixed Bugs
    + Javadoc is missing its Overview page.
    + Remove -nouses directive from maven-bundle-plugin. OSGi
    package imports now state 'uses' definitions for package
    imports, this doesn't affect JPMS (from
    org.apache.commons:commons-parent:80).
  * Changes
    + Bump org.apache.commons:commons-parent from 72 to 81 #285,
    [#287], #295, #298, #303, #310, #339.
    + Bump org.apache.commons:commons-lang3 from 3.16.0 to 3.17.0
    [#288] [test].
    + Bump log4j2.version from 2.23.1 to 2.24.3 #292, #299, #319,
    [#328].
  * Removed:
    + Remove "cobertura" plugin use JaCoco, Cobertura is
    unmaintained.
* Tue Oct 29 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to 1.3.4
  * Bug fix:
    + LOGGING-192: Fix factory loading from context class
    loader #280, #281.
* Fri Aug  9 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to 1.3.3
  * Bug Fixes:
    + LOGGING-193: Update Log4j 2 OSGi imports #268.
    + Fix PMD UnnecessaryFullyQualifiedName in SimpleLog.
    + Fix NullPointerException in SimpleLog#write(Object) on null
    input.
    + Fix NullPointerException in SimpleLog#write(StringBuffer) on
    null input.
- Includes changes from 1.3.2
  * Fixed Bugs
    + LOGGING-190: Add OSGi metadata to enable Service Loader
    Mediator #234.
    + LOGGING-191: Apache commons logging shows 1.4 as latest
    release instead of 1.3.1.
    + Deprecate
    org.apache.commons.logging.LogSource.jdk14IsAvailable.
- Includes changes from 1.3.1
  * New features
    + Add Maven property project.build.outputTimestamp for build
    reproducibility.
  * Fixed Bugs
    + Remove references to very old JDK and Commons Logging
    versions #201.
    + Update from Logj 1 to the Log4j 2 API compatibility layer
    [#231].
    + Allow Servlet 4 in OSGi environment #191.
    + Fix generics warnings #213.
    + LOGGING-189: Fix Import-Package entry for org.slf4j #188.
- Includes changes from 1.3.0
  * New Features:
    + Add support for Log4j API and SLF4J #177.
    + Deprecate org.apache.commons.logging.impl.WeakHashtable
    without replacement.  LOGGING-188: Deprecate and disable
    `Jdk13LumberjackLogger` and `Log4JLogger`.  LOGGING-173:
    + Deprecate and disable `AvalonLogger` and `LogKitLogger`.
    + LOGGING-165: Add Automatic-Module-Name Manifest Header for
    Java 9 compatibility.
  * Fixed Bugs:
    + LOGGING-163: BufferedReader is not closed properly.
    + LOGGING-177: Remove redundant initializer #46
    + Use a weak reference for the cached class loader #71.
    + Add more entries to .gitignore file #25.
    + Minor Improvements #34.
    + [StepSecurity] ci: Harden GitHub Actions #145.
    + LOGGING-185: Replace custom code with `ServiceLoader` call.
    + Fix possible NPEs in LogFactoryImpl.
    + LOGGING-185: Fix failing tests #180.
    + Deprecate LogConfigurationException.cause in favor of
    getCause().
    + Fix SpotBugs [ERROR] High: Found reliance on default encoding
    in org.apache.commons.logging.LogFactory.initDiagnostics():
    new java.io.PrintStream(OutputStream)
    [org.apache.commons.logging.LogFactory] At
    LogFactory.java:[line 1205] DM_DEFAULT_ENCODING.
    + Fix SpotBugs [ERROR] Medium: Class
    org.apache.commons.logging.impl.WeakHashtable defines
    non-transient non-serializable instance field queue
    [org.apache.commons.logging.impl.WeakHashtable] In
    WeakHashtable.java SE_BAD_FIELD.
    + Set java.logging as optional module #183.
    + Fix SpotBugs [ERROR] Medium: Switch statement found in
    org.apache.commons.logging.impl.SimpleLog.log(int, Object,
    Throwable) where default case is missing
    [org.apache.commons.logging.impl.SimpleLog] At
    SimpleLog.java:[lines 505-522] SF_SWITCH_NO_DEFAULT.
    + Deprecate
    org.apache.commons.logging.impl.Jdk13LumberjackLogger.dummyLevel
    without replacement.
- Remove deprecated patch files:
  * commons-logging-1.1.3-src-junit.diff
  * commons-logging-1.2-sourcetarget.patch
  * commons-logging-manifests.patch
  * no-tests.patch
- Reinstate ant build (removed upstream)
  * add build.xml
  * add build.properties
- Remove unnecessary dependencies
  * add commons-logging-1.3.3-dependencies.patch
- Add upstream dev's public key to apache-commons-logging.keyring
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Wed Jul 28 2021 Fridrich Strba <fstrba@suse.com>
- Disable tests everywhere, not only for arm6
* Wed Mar 24 2021 Fridrich Strba <fstrba@suse.com>
- Added patch
  * no-tests.patch
    + ignore failing tests for arm6
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against the new compatibility log4j12-mini package
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Remove pom parent, since we don't use it when not building with
  maven
- Use the pom.xml distributed with the package instead of
  downloading the same file as a separate source
* Wed Feb  6 2019 Fridrich Strba <fstrba@suse.com>
- Build against glassfish-servlet-api
* Mon Jan 28 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * commons-logging-manifests.patch
    + Different Bundle-SymbolicName for different jars
* Fri Oct 19 2018 Fridrich Strba <fstrba@suse.com>
- Cleanup of maven pom files installation
* Tue May 15 2018 fstrba@suse.com
- Modified patch:
  * commons-logging-1.2-sourcetarget.patch
    + Build with source and target 8 to prepare for a possible
    removal of 1.6 compatibility
* Thu Sep  7 2017 fstrba@suse.com
- Added patch:
  * commons-logging-1.2-sourcetarget.patch
  - set java source and target versions to 1.6 in order to allow
    build with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Remove bootstrap conditional
* Fri May 19 2017 pcervinka@suse.com
- New build dependency: javapackages-local
- Fixed requires
* Sun Jan 24 2016 p.drouand@gmail.com
- Update to version 1.2
  see http://commons.apache.org/proper/commons-logging/changes-report.html
  or RELEASE-NOTES.txt for details
* Wed Mar 25 2015 tchvatal@suse.com
- Drop maven conditionals that were never triggered.
* Wed Mar 25 2015 tchvatal@suse.com
- Drop gpg offline and rely on service
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar  4 2015 tchvatal@suse.com
- Use log4j-mini to hopefully avoid build-cycle
* Fri Feb 20 2015 dmacvicar@suse.de
- add the log4j adapter to commons-logging-adapters
  (bnc#918852)
* Tue Aug 12 2014 lnussel@suse.de
- add bcond java_bootstrap to build without unit tests
  (commons-logging-1.1.3-src-junit.diff)
* Fri Jun 27 2014 tchvatal@suse.com
- Provides obsoletes to be versioned
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Aug 27 2013 mvyskocil@suse.com
- update to 1.1.3 (bugfix release)
  see http://commons.apache.org/proper/commons-logging/changes-report.html
  or RELEASE-NOTES.txt for details
- add gpg verification
- use new add_maven_depmap from javapackages-tools
- dropped unecessary patches/sources
  * build.xml.patch
  * commons-logging-eclipse-manifest.patch
  * commons-logging-maven-release-plugin.patch
  * and commons-logging.depmap
* Mon Apr  2 2012 mvyskocil@suse.cz
- provide commons-logging
* Tue Feb 28 2012 mvyskocil@suse.cz
- fix build cycle, do not require avalon-* for build and use servletapi5
  instead of tomcat6 package
* Wed Feb  8 2012 mvyskocil@suse.cz
- rename to apache-commons-logging to follow jpackage and Fedora
- update to 1.1.1 (bugfix release)
  * usable under security policy (catches SecurityException)
  * show content of chained exceptions
  * fix unit tests on linux an java6
  * provide maven2 pom file
  * fix thread-safety bug
* Sat Aug 27 2011 andrea.turrini@gmail.com
- fixed typos in jakarta-commons-logging.spec
* Wed Jul 16 2008 coolo@suse.de
- trying to reduce build requires
* Tue May  8 2007 kesselborn@suse.de
- remove avalon references ... avalon is dropped and support for it hence not needed
* Mon Sep 25 2006 skh@suse.de
- fix BuildRequires
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jul 27 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 1.0.4 from JPackage.org
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires of javadoc subpackage
* Sun Sep  5 2004 skh@suse.de
- Initial package created with version 1.0.4 (JPackage 1.5)
